summaryrefslogtreecommitdiff
path: root/sc
diff options
context:
space:
mode:
authorTor Lillqvist <tml@collabora.com>2013-11-06 15:25:31 +0200
committerTor Lillqvist <tml@collabora.com>2013-11-07 21:07:48 +0200
commitaaa0ead88ce9bc8a94dbe3db82465cc5599c7dc9 (patch)
tree0dc39ba9cb18a9a65db62b1311d795a29a75c4a0 /sc
parent761959e7af3ea0b7b80f33f511feec212b9dc7d0 (diff)
Umgekehrte Polnische Notation is German for Reverse Polish Notation
Change-Id: I80480f963b643596ff1c0e93af3eaa6ffc63c9dd
Diffstat (limited to 'sc')
-rw-r--r--sc/source/core/data/conditio.cxx2
-rw-r--r--sc/source/core/data/formulacell.cxx10
2 files changed, 6 insertions, 6 deletions
diff --git a/sc/source/core/data/conditio.cxx b/sc/source/core/data/conditio.cxx
index cd1d2dfef97a..1a9f8698f760 100644
--- a/sc/source/core/data/conditio.cxx
+++ b/sc/source/core/data/conditio.cxx
@@ -570,7 +570,7 @@ void ScConditionEntry::UpdateMoveTab( sc::RefUpdateMoveTabContext& rCxt )
static bool lcl_IsEqual( const ScTokenArray* pArr1, const ScTokenArray* pArr2 )
{
- // verglichen wird nur das nicht-UPN Array
+ // verglichen wird nur das nicht-RPN Array
if ( pArr1 && pArr2 )
{
diff --git a/sc/source/core/data/formulacell.cxx b/sc/source/core/data/formulacell.cxx
index b0ffb74fa2bf..5e92efa27a5b 100644
--- a/sc/source/core/data/formulacell.cxx
+++ b/sc/source/core/data/formulacell.cxx
@@ -559,7 +559,7 @@ ScFormulaCell::ScFormulaCell(
mbNeedsNumberFormat( false ),
aPos( rPos )
{
- // UPN-Array generation
+ // RPN array generation
if( pCode->GetLen() && !pCode->GetCodeError() && !pCode->GetCodeLen() )
{
ScCompiler aComp( pDocument, aPos, *pCode);
@@ -995,7 +995,7 @@ void ScFormulaCell::CalcAfterLoad()
bDirty = true;
bNewCompiled = true;
}
// The UPN array is not created when a Calc 3.0-Doc has been read as the Range Names exist until now.
if( pCode->GetLen() && !pCode->GetCodeLen() && !pCode->GetCodeError() )
{
ScCompiler aComp(pDocument, aPos, *pCode);
@@ -1312,7 +1312,7 @@ void ScFormulaCell::InterpretTail( ScInterpretTailParameter eTailParam )
nSeenInIteration = pDocument->GetRecursionHelper().GetIteration();
if( !pCode->GetCodeLen() && !pCode->GetCodeError() )
{
// #i11719# no UPN and no error and no token code but result string present
// => interpretation of this cell during name-compilation and unknown names
// => can't exchange underlying code array in CompileTokenArray() /
// Compile() because interpreter's token iterator would crash or pCode
@@ -1326,7 +1326,7 @@ void ScFormulaCell::InterpretTail( ScInterpretTailParameter eTailParam )
pCode->SetCodeError( errNoCode );
// This is worth an assertion; if encountered in daily work
// documents we might need another solution. Or just confirm correctness.
- OSL_FAIL( "ScFormulaCell::Interpret: no UPN, no error, no token, but hybrid formula string" );
+ OSL_FAIL( "ScFormulaCell::Interpret: no RPN, no error, no token, but hybrid formula string" );
return;
}
CompileTokenArray();
@@ -1593,7 +1593,7 @@ void ScFormulaCell::InterpretTail( ScInterpretTailParameter eTailParam )
else
{
// Cells with compiler errors should not be marked dirty forever
- OSL_ENSURE( pCode->GetCodeError(), "no UPN-Code und no errors ?!?!" );
+ OSL_ENSURE( pCode->GetCodeError(), "no RPN code und no errors ?!?!" );
bDirty = false;
bTableOpDirty = false;
}
@@ -995,7 +995,7 @@ void ScFormulaCell::CalcAfterLoad()
bNewCompiled = true;
}
- // The UPN array is not created when a Calc 3.0-Doc has been read as the Range Names exist until now.
+ // The RPN array is not created when a Calc 3.0-Doc has been read as the Range Names exist until now.
if( pCode->GetLen() && !pCode->GetCodeLen() && !pCode->GetCodeError() )
{
@@ -1312,7 +1312,7 @@ void ScFormulaCell::InterpretTail( ScInterpretTailParameter eTailParam )
if( !pCode->GetCodeLen() && !pCode->GetCodeError() )
{
- // #i11719# no UPN and no error and no token code but result string present
+ // #i11719# no RPN and no error and no token code but result string present
// => interpretation of this cell during name-compilation and unknown names
// => can't exchange underlying code array in CompileTokenArray() /